@@ -19,8 +19,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GSSDP_ERROR_H__
-#define __GSSDP_ERROR_H__
+#ifndef GSSDP_ERROR_H
+#define GSSDP_ERROR_H
 
 #include <glib.h>
 
@@ -31,6 +31,12 @@ gssdp_error_quark (void) G_GNUC_CONST;
 
 #define GSSDP_ERROR (gssdp_error_quark ())
 
+/**
+ * GSSDPError:
+ * @GSSDP_ERROR_NO_IP_ADDRESS: GSSDP could not find a valid IP address of a
+ * #GSSDPClient.
+ * @GSSDP_ERROR_FAILED: Unknown error.
+ */
 typedef enum {
         GSSDP_ERROR_NO_IP_ADDRESS,
         GSSDP_ERROR_FAILED
@@ -38,4 +44,4 @@ typedef enum {
 
 G_END_DECLS
 
-#endif /* __GSSDP_ERROR_H__ */
+#endif /* GSSDP_ERROR_H */
