@@ -72,6 +72,7 @@ create_alive_message (const char *nt)
                 usn = g_strconcat (UUID_1, "::", nt, NULL);
 
         msg = g_strdup_printf (SSDP_ALIVE_MESSAGE "\r\n",
+                               SSDP_ADDR,
                                1800,
                                "http://127.0.0.1:1234",
                                "",
@@ -93,7 +94,7 @@ create_byebye_message (const char *nt)
         else
                 usn = g_strconcat (UUID_1, "::", nt, NULL);
 
-        msg = g_strdup_printf (SSDP_BYEBYE_MESSAGE "\r\n", nt, usn);
+        msg = g_strdup_printf (SSDP_BYEBYE_MESSAGE "\r\n", SSDP_ADDR, nt, usn);
         g_free (usn);
 
         return msg;
