@@ -66,20 +66,24 @@ get_client (GError **outer_error)
 
                 g_debug ("Detecting network interface to use for tests...");
 
-                client = g_initable_new (GSSDP_TYPE_CLIENT,
-                                         NULL,
-                                         &error,
-                                         "host-ip", "127.0.0.1",
-                                         NULL);
+                client = gssdp_client_new ("lo", &error);
                 if (error == NULL) {
-                        device = g_strdup (gssdp_client_get_interface (client));
-                        g_debug ("Using %s", device);
+                        g_debug ("Using lo");
+                        device = g_strdup ("lo");
                         g_object_unref (client);
                 } else {
-                        g_debug ("Using default interface, expect fails");
+                        g_clear_error(&error);
+                        client = gssdp_client_new ("lo0", &error);
+                        if (error == NULL) {
+                                g_debug ("Using lo0");
+                                device = g_strdup ("lo0");
+                                g_object_unref (client);
+                        } else {
+                                g_debug ("Using default interface, expect fails");
+                        }
                 }
                 g_once_init_leave (&init_guard, 1);
         }
 
-        return gssdp_client_new (NULL, device, outer_error);
+        return gssdp_client_new (device, outer_error);
 }
